export interface ResolveModuleOptions {
    baseDir: string;
    /**
     * When resolution reach package.json returns the path to the file relative to it.
     * @default pkg.main
     */
    resolveMain?: (pkg: any) => string;
    /**
     * When resolution reach a directory without package.json look for those files to load in order.
     * @default ["index.mjs", "index.js"]
     */
    directoryIndexFiles?: string[];
}
export interface ResolveModuleHost {
    /**
     * Resolve the real path for the current host.
     */
    realpath(path: string): Promise<string>;
    /**
     * Get information about the given path
     */
    stat(path: string): Promise<{
        isDirectory(): boolean;
        isFile(): boolean;
    }>;
    /**
     * Read a utf-8 encoded file.
     */
    readFile(path: string): Promise<string>;
}
/**
 * Type for package.json https://docs.npmjs.com/cli/v8/configuring-npm/package-json
 */
export interface NodePackage {
    name: string;
    description?: string;
    type?: "module" | "commonjs";
    main?: string;
    version: string;
    tspMain?: string;
    homepage?: string;
    bugs?: {
        url?: string;
        email?: string;
    };
    private?: boolean;
    dependencies?: Record<string, string>;
    peerDependencies?: Record<string, string>;
    devDependencies?: Record<string, string>;
}
type ResolveModuleErrorCode = "MODULE_NOT_FOUND" | "INVALID_MAIN";
export declare class ResolveModuleError extends Error {
    code: ResolveModuleErrorCode;
    constructor(code: ResolveModuleErrorCode, message: string);
}
export type ModuleResolutionResult = ResolvedFile | ResolvedModule;
export interface ResolvedFile {
    type: "file";
    path: string;
}
export interface ResolvedModule {
    type: "module";
    /**
     * Root of the package. (Same level as package.json)
     */
    path: string;
    /**
     * Resolved main file for the module.
     */
    mainFile: string;
    /**
     * Value of package.json.
     */
    manifest: NodePackage;
}
/**
 * Resolve a module
 * @param host
 * @param name
 * @param options
 * @returns
 */
export declare function resolveModule(host: ResolveModuleHost, name: string, options: ResolveModuleOptions): Promise<ModuleResolutionResult>;
export {};
//# sourceMappingURL=module-resolver.d.ts.map