import { Checker } from "./checker.js";
import { CompilerOptions } from "./options.js";
import { StateMap, StateSet } from "./state-accessors.js";
import { CompilerHost, Diagnostic, EmitterFunc, JsSourceFileNode, LibraryMetadata, LiteralType, LocationContext, Namespace, ProjectionApplication, Projector, SourceFile, SymbolTable, Tracer, Type, TypeSpecScriptNode } from "./types.js";
export interface ProjectedProgram extends Program {
    projector: Projector;
}
export declare function projectProgram(program: Program, projections: ProjectionApplication[], startNode?: Type): ProjectedProgram;
export interface Program {
    compilerOptions: CompilerOptions;
    mainFile?: TypeSpecScriptNode;
    /** All source files in the program, keyed by their file path. */
    sourceFiles: Map<string, TypeSpecScriptNode>;
    jsSourceFiles: Map<string, JsSourceFileNode>;
    literalTypes: Map<string | number | boolean, LiteralType>;
    host: CompilerHost;
    tracer: Tracer;
    trace(area: string, message: string): void;
    checker: Checker;
    emitters: EmitterRef[];
    readonly diagnostics: readonly Diagnostic[];
    loadTypeSpecScript(typespecScript: SourceFile): Promise<TypeSpecScriptNode>;
    onValidate(cb: (program: Program) => void | Promise<void>, LibraryMetadata: LibraryMetadata): void;
    getOption(key: string): string | undefined;
    stateSet(key: symbol): Set<Type>;
    stateSets: Map<symbol, StateSet>;
    stateMap(key: symbol): Map<Type, any>;
    stateMaps: Map<symbol, StateMap>;
    hasError(): boolean;
    reportDiagnostic(diagnostic: Diagnostic): void;
    reportDiagnostics(diagnostics: readonly Diagnostic[]): void;
    reportDuplicateSymbols(symbols: SymbolTable | undefined): void;
    getGlobalNamespaceType(): Namespace;
    resolveTypeReference(reference: string): [Type | undefined, readonly Diagnostic[]];
    /** Return location context of the given source file. */
    getSourceFileLocationContext(sourceFile: SourceFile): LocationContext;
    /**
     * Project root. If a tsconfig was found/specified this is the directory for the tsconfig.json. Otherwise directory where the entrypoint is located.
     */
    readonly projectRoot: string;
}
interface EmitterRef {
    emitFunction: EmitterFunc;
    main: string;
    metadata: LibraryMetadata;
    emitterOutputDir: string;
    options: Record<string, unknown>;
}
export declare function compile(host: CompilerHost, mainFile: string, options?: CompilerOptions, oldProgram?: Program): Promise<Program>;
export {};
//# sourceMappingURL=program.d.ts.map